'use strict';

exports.__esModule = true;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _helper = require('./Shared/helper.js');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

//component - CoreUI / CButton

var CButton = function CButton(props) {
  var Tag = props.tag,
      children = props.children,
      className = props.className,
      cssModule = props.cssModule,
      innerRef = props.innerRef,
      active = props.active,
      ariaLabel = props['aria-label'],
      block = props.block,
      close = props.close,
      color = props.color,
      size = props.size,
      textHtml = props.textHtml,
      pressed = props.pressed,
      shape = props.shape,
      variant = props.variant,
      attributes = _objectWithoutProperties(props, ['tag', 'children', 'className', 'cssModule', 'innerRef', 'active', 'aria-label', 'block', 'close', 'color', 'size', 'textHtml', 'pressed', 'shape', 'variant']);

  var onClick = function onClick(e) {
    if (props.disabled) {
      e.preventDefault();
      return;
    }
    if (props.onClick) {
      props.onClick(e);
    }
  };

  //render

  if (close && typeof children === 'undefined') {
    children = _react2.default.createElement(
      'span',
      { 'aria-hidden': true },
      '\xD7'
    );
  }

  var btnColor = 'btn' + (variant ? '-' + variant : '') + '-' + color;

  var classes = (0, _helper.mapToCssModules)((0, _classnames2.default)(className, { close: close }, close || 'btn', close || btnColor, size ? 'btn-' + size : false, block ? 'btn-block' : false, shape ? 'btn-' + shape : false, pressed ? 'btn-pressed' : false, { 'active': active,
    'disabled': props.disabled }), cssModule);

  if (attributes.href && Tag === 'button') {
    Tag = 'a';
  }

  var defaultAriaLabel = close ? 'Close' : null;

  return _react2.default.createElement(Tag, _extends({
    type: Tag === 'button' && attributes.onClick ? 'button' : undefined
  }, attributes, {
    className: classes,
    onClick: onClick,
    'aria-label': ariaLabel || defaultAriaLabel,
    ref: innerRef,
    children: textHtml ? textHtml : children
  }));
};

CButton.propTypes = process.env.NODE_ENV !== "production" ? {
  tag: _helper.tagPropType,
  children: _propTypes2.default.node,
  cssModule: _propTypes2.default.object,
  className: _propTypes2.default.string,
  //
  innerRef: _propTypes2.default.oneOfType([_propTypes2.default.object, _propTypes2.default.func, _propTypes2.default.string]),
  active: _propTypes2.default.bool,
  block: _propTypes2.default.bool,
  shape: _propTypes2.default.string,
  variant: _propTypes2.default.oneOf(['', 'ghost', 'outline']),
  color: _propTypes2.default.string,
  close: _propTypes2.default.bool,
  disabled: _propTypes2.default.bool,
  onClick: _propTypes2.default.func,
  size: _propTypes2.default.string,
  pressed: _propTypes2.default.bool,
  textHtml: _propTypes2.default.string,
  'aria-label': _propTypes2.default.string
} : {};

CButton.defaultProps = {
  tag: 'button'
};

//export
exports.default = CButton;
module.exports = exports['default'];