'use strict';

exports.__esModule = true;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _helper = require('./Shared/helper.js');

var _CDropdownCustom = require('./CDropdownCustom');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

//component - CoreUI / CDropdownItem

var CDropdownItem = function CDropdownItem(props) {
  var _omit = (0, _helper.omit)(props, ['toggle']),
      Tag = _omit.tag,
      className = _omit.className,
      cssModule = _omit.cssModule,
      innerRef = _omit.innerRef,
      color = _omit.color,
      divider = _omit.divider,
      header = _omit.header,
      active = _omit.active,
      attributes = _objectWithoutProperties(_omit, ['tag', 'className', 'cssModule', 'innerRef', 'color', 'divider', 'header', 'active']);

  var context = (0, _react.useContext)(_CDropdownCustom.Context);

  var onClick = function onClick(e) {
    if (props.disabled || props.header || props.divider) {
      e.preventDefault();
      return;
    }
    if (props.onClick) {
      props.onClick(e);
    }
    if (props.toggle) {
      context.toggle(e);
    }
  };

  var getTabIndex = function getTabIndex() {
    if (props.disabled || props.header || props.divider) {
      return '-1';
    }
    return '0';
  };

  //render

  var tabIndex = getTabIndex();
  var role = tabIndex > -1 ? 'menuitem' : undefined;

  var classes = (0, _helper.mapToCssModules)((0, _classnames2.default)(className, header ? 'dropdown-header' : divider ? 'dropdown-divider' : 'dropdown-item', active ? 'active' : null, color ? 'bg-' + color : null, {
    disabled: attributes.disabled
  }), cssModule);

  if (Tag === 'button') {
    if (header) {
      Tag = 'h6';
    } else if (divider) {
      Tag = 'div';
    } else if (props.href) {
      Tag = 'a';
    }
  }

  return _react2.default.createElement(Tag, _extends({
    type: Tag === 'button' && (attributes.onClick || props.toggle) ? 'button' : undefined
  }, attributes, {
    tabIndex: tabIndex,
    role: role,
    className: classes,
    onClick: onClick,
    ref: innerRef
  }));
};

CDropdownItem.propTypes = process.env.NODE_ENV !== "production" ? {
  tag: _helper.tagPropType,
  children: _propTypes2.default.node,
  className: _propTypes2.default.string,
  cssModule: _propTypes2.default.object,
  //
  innerRef: _propTypes2.default.oneOfType([_propTypes2.default.object, _propTypes2.default.func, _propTypes2.default.string]),
  color: _propTypes2.default.string,
  divider: _propTypes2.default.bool,
  header: _propTypes2.default.bool,
  active: _propTypes2.default.bool,
  disabled: _propTypes2.default.bool,
  onClick: _propTypes2.default.func,
  toggle: _propTypes2.default.bool
} : {};

CDropdownItem.defaultProps = {
  tag: 'button',
  toggle: true
};

exports.default = CDropdownItem;
module.exports = exports['default'];